<?xml version="1.0" encoding="UTF-8"?>
<!--
***************************************
Script to output a simple HTML representation of a service description which uses the ServiceDescription schema
***************************************
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
	xmlns:ssd="https://governance.eur.swim.aero/SWIM/ServiceDescription/1" 
	xmlns:gen="https://governance.eur.swim.aero/SWIM/ServiceDescription/1/general" 
	xmlns:abs= "https://governance.eur.swim.aero/SWIM/ServiceDescription/1/abstract" 
	xmlns:con= "https://governance.eur.swim.aero/SWIM/ServiceDescription/1/concrete"  
	xmlns:ti="https://governance.eur.swim.aero/SWIM/SWIMTI/1">
	<xsl:output method="html" version="5.0" encoding="UTF-8" indent="yes"/>
	<!--
Set up the header and titles
***************************************
-->
	<xsl:template name="replace">
    <xsl:param name="string"/>
    <xsl:choose>
        <xsl:when test="contains($string,'&#10;')">
            <xsl:value-of select="substring-before($string,'&#10;')"/>
            <br/>
            <xsl:call-template name="replace">
                <xsl:with-param name="string" select="substring-after($string,'&#10;')"/>
            </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="$string"/>
        </xsl:otherwise>
    </xsl:choose>
	</xsl:template>

	<xsl:template match="ssd:swimServiceDescription">
		<html>
			<head>
				<title>
					<xsl:value-of select="ssd:generalDescription/gen:title"/>
				</title>
				<link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.1.3/css/bootstrap.min.css" integrity="sha384-MCw98/SFnGE8fJT3GXwEOngsV7Zt27NXFoaoApmYm81iuXoPkFOJwJ8ERdknLPMO" crossorigin="anonymous"/>
				<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/open-iconic/1.1.1/font/css/open-iconic-bootstrap.min.css" />
				<script src="https://code.jquery.com/jquery-3.3.1.slim.min.js" integrity="sha384-q8i/X+965DzO0rT7abK41JStQIAqVgRVzpbzo5smXKp4YfRvH+8abtTE1Pi6jizo" crossorigin="anonymous"></script>
				<script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.3/umd/popper.min.js" integrity="sha384-ZMP7rVo3mIykV+2+9J3UJ46jBk0WLaUAdn689aCwoqbBJiSnjAK/l8WvCWPIPm49" crossorigin="anonymous"></script>
				<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.1.3/js/bootstrap.min.js" integrity="sha384-ChfqqxuZUCnJSK3+MXmPNIyE6ZbWh2IMqE241rYiqJxyMiZ6OW/JmZQ5stwEULTy" crossorigin="anonymous"></script>
				<script>
					$(function () {
					  $('[data-toggle="popover"]').popover()
					})
					$('.popover-dismiss').popover({
					  trigger: 'focus'
					})
					
					var shiftWindow = function() { scrollBy(0, -70) };
					if (location.hash) shiftWindow();
					window.addEventListener("hashchange", shiftWindow);
				</script>
				<!-- <link rel="stylesheet" href="./css/basic_style.css" type="text/css"/>-->
			</head>
			<body >


			<div class="container-fluid">
				<h1 class="display-2">
					<xsl:value-of select="ssd:generalDescription/gen:title"/>
				</h1>
				<h2>Edition: <xsl:value-of select="@edition"/>, <xsl:value-of select="@refDate"/></h2>
				<nav class="navbar sticky-top navbar-expand-lg navbar-light bg-light">
				  <a class="navbar-brand" href="#">SWIM Service</a>
				  <div class="collapse navbar-collapse" id="navbarNavAltMarkup">
				    <div class="navbar-nav">
				      <a class="nav-item nav-link active" href="#general">General</a>
				      <a class="nav-item nav-link" href="#abstract">Abstract</a>
				      <a class="nav-item nav-link" href="#concrete">Concrete</a>
				      <div class="dropdown show">
				      <a class="nav-link dropdown-toggle" href="#" id="navbarDropdownMenuLink" data-toggle="dropdown" >
				          Abbreviations
				     </a>
				     <xsl:apply-templates select="//ssd:generalDescription/gen:abbreviationList"/>
				     </div>
			        </div>
				    
				  </div>
				</nav>
				<xsl:apply-templates/>
			</div>
			</body>
		</html>
	</xsl:template>
	
	<!--
***************************************
General Description
***************************************
-->

	<xsl:template match="gen:abbreviationList">
		 <div class="dropdown-menu" aria-labelledby="navbarDropdownMenuLink">
          <xsl:apply-templates/>
        </div>
	</xsl:template>
	
	<xsl:template match="gen:abbrev">
          <a class="dropdown-item" href="#" style="font-size: 10px;"><xsl:value-of select="@short"/> : <xsl:value-of select="."></xsl:value-of></a>
	</xsl:template>

	<xsl:template match="ssd:generalDescription">
		<div class="shadow p-3 mb-5 rounded" style="width: 80%; background-color: #fee; margin: auto;" id="general">
			<h1>General Description</h1>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:title">
		<div>
			<div class="badge badge-primary">Title:</div>&#160;
			<xsl:value-of select="."/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:serviceIdentification">
		<div>
			<div class="badge badge-primary">Service Name:</div>&#160; <xsl:value-of select="gen:serviceName"/>&#160;
			<div class="badge badge-primary">Service Version:</div>&#160; <xsl:value-of select="gen:serviceVersion"/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:serviceAbstract">
		<div>
			<div class="badge badge-primary">Abstract: </div>
			<p><xsl:value-of select="."/></p>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:serviceProvider">
		<div>
			<h2>Provider Information</h2>
			<div class="badge badge-primary">Provider Name:</div>&#160; <xsl:value-of select="gen:name"/>&#160;
			<div class="badge badge-primary">Description:</div>&#160; <xsl:value-of select="gen:description"/>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:pointOfContact">
		<div>
			<div class="badge badge-primary">Name:</div>&#160; <xsl:value-of select="gen:name"/>&#160;
			<div class="badge badge-primary">E-Mail:</div>&#160; <xsl:value-of select="gen:email"/>
			<div class="badge badge-primary">URL:</div>&#160; <a><xsl:attribute name="href"><xsl:value-of select="gen:url"/></xsl:attribute>
				</a>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:serviceCategory">
			<h2>Categories</h2> 
				<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="gen:informationExchangeArea">
		<div>
			<div class="badge badge-primary">Information Exchange Area:</div>&#160; 
			<xsl:value-of select="." />
		</div>
	</xsl:template>
	
	<xsl:template match="gen:geoExtent">
		<div>
			<div class="badge badge-primary">Geographical Extent:</div>&#160; 
			<xsl:value-of select="." />
		</div>
	</xsl:template>
	
	<xsl:template match="gen:intendedServiceConsumer">
		<div>
			<div class="badge badge-primary">Intended Service Consumer:</div>&#160; 
			<xsl:value-of select="." />
		</div>
	</xsl:template>
	
	<xsl:template match="gen:businessActivity">
		<div>
			<div class="badge badge-primary">Business Activity:</div>&#160; 
			<xsl:value-of select="." />
			<xsl:for-each select="*">
		        <xsl:value-of select="local-name(.)"/>
		         <xsl:value-of select="."/> <br/>
		    </xsl:for-each>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:lifecycleStatus">
		<div>
			<div class="badge badge-primary">Lifecycle Status:</div>&#160; 
			<xsl:value-of select="." />
		</div>
	</xsl:template>
	
	<xsl:template match="gen:standard">
		<div>
			<h2>Standard</h2>
			<div class="badge badge-primary">name:</div>&#160; <xsl:value-of select="gen:name"/>&#160;
			<div class="badge badge-primary">version:</div>&#160; <xsl:value-of select="gen:version"/>&#160;<br/>
			<div class="badge badge-primary">link:</div>&#160; <a><xsl:attribute name="href"><xsl:value-of select="gen:complianceRef"/></xsl:attribute>
				<xsl:value-of select="gen:complianceRef"/>
				</a>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:operationalNeedList">
		<div>
			<h2>Operational Needs:</h2>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:operationalNeed">
			
			<p> <div class="badge badge-primary">Operational Need</div>
				<xsl:call-template name="replace">
			        <xsl:with-param name="string" select="."/>
			    </xsl:call-template>
			</p>
	</xsl:template>
	
	<xsl:template match="gen:informationExchangeRequirementList">
		<div>
			<h2>Information Exchange Requirements:</h2>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:ier">
		<div>
		<div class="badge badge-primary"><xsl:value-of select="@source"/></div>&#160;
		<div class="badge badge-primary"><xsl:value-of select="@id"/></div>&#160;
		<xsl:value-of select="."/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:functionList">
		<div>
			<h2>Functions:</h2>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:functionality">
		<div>
		<div class="badge badge-primary">function</div>&#160;<xsl:value-of select="./gen:function"/>&#160;
		<div class="badge badge-primary">real world effect</div>&#160;<xsl:value-of select="./gen:realWorldEffect"/>&#160;
		</div>
	</xsl:template>
	
	<xsl:template match="gen:serviceBehaviour">
		<div>
			<h2>Service Behaviour:</h2>
			<div class="badge badge-primary">Description</div>&#160;<xsl:value-of select="./gen:behaviourDescription"/>&#160;<br/>
			<div class="badge badge-primary">Document</div>&#160;
			<a>
				<xsl:attribute name="href"><xsl:value-of select="./gen:behaviourDescriptionDocument"/></xsl:attribute>
				<xsl:value-of select="./gen:behaviourDescriptionDocument"/>
			</a>&#160;<br/>
			<div class="badge badge-primary">UML</div>&#160;
			<a>
				<xsl:attribute name="href"><xsl:value-of select="./gen:umlBehaviour"/></xsl:attribute>
				<xsl:value-of select="./gen:umlBehaviour"/>
			</a>&#160;<br/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:accessAndUseConditions">
		<div>
		<h2>Access and Use Conditions</h2>
		<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:legalConstraint">
		<div>
		<div class="badge badge-primary">Legal Constraint</div>&#160;<xsl:value-of select="."/>&#160;<br/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:servicePolicy">
		<div>
		<div class="badge badge-primary">Service Policy</div>&#160;<xsl:value-of select="."/>&#160;<br/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:serviceConsumptionConstraint">
		<div>
		<div class="badge badge-primary">Service Consumption Constraint</div>&#160;<xsl:value-of select="."/>&#160;<br/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:securityConstraint">
		<div>
		<div class="badge badge-primary">Security Constraint</div>&#160;<xsl:value-of select="."/>&#160;<br/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:qualityOfService">
		<div>
		<h2>Quality of Service</h2>
		<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:serviceAvailability">
		<div>
		<div class="badge badge-primary">Service Availability</div>&#160;<xsl:value-of select="."/>&#160;<br/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:serviceResponseTime">
		<div>
		<div class="badge badge-primary">Response Time</div>&#160;<xsl:value-of select="."/>&#160;<br/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:serviceThroughput">
		<div>
		<div class="badge badge-primary">Throughput</div>&#160;<xsl:value-of select="."/>&#160;<br/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:technicalConstraint">
		<div>
		<div class="badge badge-primary">Technical Constraint</div>&#160;<xsl:value-of select="."/>&#160;<br/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:airmConformanceStatement">
		<div>
			<h2>AIRM conformance</h2>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="gen:airmConform">
		<div>
		<div class="badge badge-success">AIRM Conform</div>&#160;
		<div class="badge badge-primary">Version</div>&#160;<xsl:value-of select="./gen:airmVersion"/>&#160;<br/>
		<div class="badge badge-primary">Comment</div>&#160;<xsl:value-of select="./gen:comments"/>&#160;<br/>
		<div class="badge badge-primary">Compliance Refernce</div>&#160;
			<a>
				<xsl:attribute name="href"><xsl:value-of select="./gen:complianceRef"/></xsl:attribute>
				<xsl:value-of select="./gen:complianceRef"/>
			</a>&#160;
		</div>
	</xsl:template>
	
	<xsl:template match="gen:validation">
		<div>
			<h2>Validation</h2>
		<xsl:value-of select="."/>&#160;
		</div>
	</xsl:template>
	
	<xsl:template match="gen:messageExchangePattern">
		<div>
			<h2>Message Exchange Patten</h2>
			<div class="badge badge-primary" >
				<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
				<xsl:value-of select="."/>
			</div>
		</div>
	</xsl:template>
	
	

<!-- 
	ABSTRACT
 -->
 
 	<xsl:template match="ssd:abstractDescription">
		<div class="shadow p-3 mb-5 rounded" style="width: 80%; background-color: #def; margin: auto;" id="abstract">
			<h1>Abstract Description</h1>
			
			<h2>Interfaces</h2>			
			<xsl:apply-templates select="abs:interface"/>
			
			<h2>Messages</h2>			
			<xsl:apply-templates select="abs:message"/>
			
			<h2>Resources</h2>			
			<xsl:apply-templates select="abs:resource"/>
		</div>
	</xsl:template>
	
	<xsl:template match="abs:interface">
		<div class="shadow p-3 mb-5 rounded" >
			<xsl:attribute name="id"><xsl:value-of select="@name"/></xsl:attribute>
		
			<h3><xsl:value-of select="@name"/></h3>
			<div class="badge badge-primary">Description</div>&#160;<xsl:value-of select="./abs:description"/>&#160;<br/>
			<div class="badge badge-primary">MEP</div>&#160;
			<a>
				<xsl:attribute name="href">#<xsl:value-of select="@serviceMEP"/></xsl:attribute>
				<span class="oi oi-link-intact" title="link"></span>
			</a>&#160;
			<h4>Operations</h4>
			<xsl:apply-templates select="abs:operation"/>
		</div>
	</xsl:template>
	
	<xsl:template match="abs:operation">
		<div class="shadow-sm p-3 mb-2 rounded">
			<div style="font-weigth: bold; font-size: 120%;"><xsl:value-of select="@name"/></div>
			<div class="badge badge-primary">Message exchange Pattern</div>&#160;<xsl:value-of select="@messageExchangePattern"/>&#160;<br/>
			<div class="badge badge-primary">Description</div>&#160;<xsl:value-of select="./abs:description"/>&#160;<br/>
			<div class="badge badge-primary">Effect</div>&#160;<xsl:value-of select="./abs:effect"/><br/>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="abs:input">
		<div class="badge badge-primary">Input</div>&#160;<xsl:value-of select="@message"/>&#160;
		<a>
			<xsl:attribute name="href">#<xsl:value-of select="@message"/></xsl:attribute>
			<span class="oi oi-link-intact" title="link"></span>
		</a><br/>
	</xsl:template>
	
	<xsl:template match="abs:output">
		<div class="badge badge-primary">Output</div>&#160;<xsl:value-of select="@message"/>&#160;
		<a>
			<xsl:attribute name="href">#<xsl:value-of select="@message"/></xsl:attribute>
			<span class="oi oi-link-intact" title="link"></span>
		</a>
		<br/>
	</xsl:template>

	<xsl:template match="abs:message">
		<div class="shadow p-3 mb-2 rounded">
			<xsl:attribute name="id"><xsl:value-of select="@name"/></xsl:attribute>
			<h3><xsl:value-of select="@name"/></h3>
			<div class="badge badge-primary">Direction</div>&#160;<xsl:value-of select="@direction"/>&#160;<br/>
			<div class="badge badge-primary">Description</div>&#160;
			<xsl:call-template name="replace">
			        <xsl:with-param name="string" select="./abs:description"/>
			    </xsl:call-template>
			&#160;<br/>
			<div class="badge badge-primary">Datatype</div>&#160;<xsl:value-of select="./abs:datatype"/>&#160;
		</div>
	</xsl:template>
	
	<xsl:template match="abs:resource">
		<div class="shadow p-3 mb-2 rounded">
			<xsl:attribute name="id"><xsl:value-of select="@name"/></xsl:attribute>
			<h2><xsl:value-of select="@name"/></h2>
			<div class="badge badge-primary">Description</div>&#160;
			<xsl:call-template name="replace">
			        <xsl:with-param name="string" select="./abs:description"/>
			    </xsl:call-template>
			&#160;<br/>
			<div class="badge badge-primary">Interface</div>&#160;<xsl:value-of select="./abs:interface"/>&#160;
			<a>
				<xsl:attribute name="href">#<xsl:value-of select="./abs:interface"/></xsl:attribute>
				<span class="oi oi-link-intact" title="link"></span>
			</a>
			<br/>
			
			<!-- Erweiterung AS      -->
			<xsl:if test="key[@name='service']">
	    	   <div class="badge badge-primary">Service</div>&#160;
	           <xsl:value-of select="key[@name='service']/value/@name"/>
	        </xsl:if>
	        &#160;<br/>
	        <xsl:if test="key[@name='version']">
	    	   <div class="badge badge-primary">Version</div>&#160;
	           <xsl:value-of select="key[@name='version']/value/@name"/>
	        </xsl:if>
	        &#160;<br/>
	        <xsl:if test="key[@name='request']">   	   	    	   
	    	   <xsl:for-each select="key[@name='request']/value">
	    	        <br/><div class="badge badge-primary">Request</div>&#160;
	    	        <xsl:value-of select="@name"/>
	    	        <xsl:if test="key">
	    	           <xsl:for-each select="key">
	    	             &#160;<div class="badge badge-primary"><xsl:value-of select="@name"/></div>&#160;
	    	             &#160;<xsl:value-of select="value/@name"/>
	    	            </xsl:for-each>
	    	        </xsl:if>
	    	   </xsl:for-each>
	        </xsl:if>
            <!-- Erweiterung AS Ende -->
			
		</div>
	</xsl:template>
	


<!-- 
	CONCRETE
 -->
 
 	<xsl:template match="ssd:concreteDescription">
		<div class="shadow p-3 mb-5 rounded" style="width: 80%; background-color: #ffd; margin: auto;" id="concrete">
			<h1>Concrete Description</h1>
			<div class="badge badge-primary">Machine Processable Description</div>&#160;<xsl:value-of select="@machineProcessableDescription"/>&#160;
			<a>
				<xsl:attribute name="href"><xsl:value-of select="@machineProcessableDescription"/></xsl:attribute>
				<span class="oi oi-link-intact" title="link"></span>
			</a>
			<h2>Endpoints</h2>
			<xsl:apply-templates select="con:endpoint"/>
			
			<h2>Bindings</h2>
			<xsl:apply-templates select="con:binding"/>
		</div>
	</xsl:template>
	
	<xsl:template match="con:endpoint">
		<div class="badge badge-primary">Endpoint</div>&#160;<xsl:value-of select="@name"/>&#160;
		<div class="badge badge-primary">Address</div>&#160;<xsl:value-of select="@address"/>&#160;
		<xsl:if test="@resource">
			<div class="badge badge-primary">Resource</div>&#160;<xsl:value-of select="@resource"/>&#160;
			<a>
				<xsl:attribute name="href">#<xsl:value-of select="@resource"/></xsl:attribute>
				<span class="oi oi-link-intact" title="link"></span>
			</a>&#160;
		</xsl:if>
		<div class="badge badge-primary">Binding</div>&#160;<xsl:value-of select="con:binding"/>&#160;
		<a>
			<xsl:attribute name="href">#<xsl:value-of select="con:binding"/></xsl:attribute>
			<span class="oi oi-link-intact" title="link"></span>
		</a><br/>
	</xsl:template>
	
	<xsl:template match="con:binding">
		<div class="shadow p-3 mb-2 rounded">
			<xsl:attribute name="id"><xsl:value-of select="@name"/></xsl:attribute>
			<div class="badge badge-primary">Name</div>&#160;<xsl:value-of select="@name"/>&#160;<br/>
			<div class="badge badge-primary">SWIM Profile</div>&#160;<xsl:value-of select="@tiProfile"/>&#160;<br/>
			<div class="badge badge-primary">Interface</div>&#160;<xsl:value-of select="@interface"/>&#160;
			<a>
				<xsl:attribute name="href">#<xsl:value-of select="@interface"/></xsl:attribute>
				<span class="oi oi-link-intact" title="link"></span>
			</a><br/>
			<div class="badge badge-primary">Description</div>&#160;<xsl:call-template name="replace">
			        <xsl:with-param name="string" select="con:description"/>
			    </xsl:call-template><br/>
			<div class="badge badge-primary">TI Version</div>&#160;<xsl:value-of select="con:tiBinding/@version"/>&#160;<br/> 
			<div class="badge badge-primary">Interface Binding</div>&#160;<xsl:value-of select="con:tiBinding/ti:yellowInterfaceBinding"/>&#160;<br/> 
			<div class="badge badge-primary">Network Binding</div>&#160;<xsl:value-of select="con:tiBinding/ti:networkBinding"/>&#160;<br/> 
						<div class="badge badge-primary">Protocol</div>&#160;<xsl:value-of select="con:tiBinding/ti:protocolList/ti:protocol/ti:name"/>&#160;<br/> 
						<div class="badge badge-primary">Protocol Version</div>&#160;<xsl:value-of select="con:tiBinding/ti:protocolList/ti:protocol/ti:version"/>&#160;<br/> 
			 <xsl:apply-templates />
		</div>
	
	</xsl:template>
	
	<xsl:template match="con:bindingOperation">
		<div class="shadow p-3 mb-2 rounded">
		<div class="badge badge-primary">Operation</div>&#160;<xsl:value-of select="@name"/>&#160;<br/>
		<div class="badge badge-primary">MEP</div>&#160;<xsl:value-of select="@messageExchangePattern"/>&#160;<br/>
		<div class="badge badge-primary">Description</div>&#160;<xsl:call-template name="replace">
			        <xsl:with-param name="string" select="con:description"/>
			    </xsl:call-template><br/>
		</div>
	</xsl:template>
	
	<!--	
***************************************
General functions - absorb anything missed by the templates
***************************************
-->
	<xsl:template match="node()"/>
</xsl:stylesheet>
